==> webkitgtk_2.4.0.orig.tar.xz: webkitgtk-2.4.0/Source/WebCore/bindings/js/JSMutationCallback.h <==
/*
 * Copyright (C) 2013 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef JSMutationCallback_h
#define JSMutationCallback_h

#include "ActiveDOMCallback.h"
#include "DOMWrapperWorld.h"
#include "MutationCallback.h"
#include <heap/Weak.h>
#include <runtime/JSObject.h>
#include <wtf/Forward.h>

namespace WebCore {

class JSDOMGlobalObject;

class JSMutationCallback : public MutationCallback, public ActiveDOMCallback {
public:
    static PassRefPtr<JSMutationCallback> create(JSC::JSObject* callback, JSDOMGlobalObject* globalObject)
    {
        return adoptRef(new JSMutationCallback(callback, globalObject));
    }

    virtual ~JSMutationCallback();

    virtual void call(const Vector<RefPtr<MutationRecord>>&, MutationObserver*) override;

    virtual ScriptExecutionContext* scriptExecutionContext() const override { return ContextDestructionObserver::scriptExecutionContext(); }

private:
    JSMutationCallback(JSC::JSObject* callback, JSDOMGlobalObject*);

    mutable JSC::Weak<JSC::JSObject> m_callback;
    RefPtr<DOMWrapperWorld> m_isolatedWorld;
};

} // namespace WebCore

#endif

==> webkitgtk-2.14.5.tar.xz: webkitgtk-2.14.5/Source/WebCore/bindings/js/JSMutationCallback.h <==
/*
 * Copyright (C) 2013 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef JSMutationCallback_h
#define JSMutationCallback_h

#include "ActiveDOMCallback.h"
#include "DOMWrapperWorld.h"
#include "MutationCallback.h"
#include <heap/Weak.h>
#include <runtime/JSObject.h>
#include <wtf/Forward.h>

namespace WebCore {

class JSDOMGlobalObject;

class JSMutationCallback final : public MutationCallback, public ActiveDOMCallback {
public:
    static Ref<JSMutationCallback> create(JSC::JSObject* callback, JSDOMGlobalObject* globalObject)
    {
        return adoptRef(*new JSMutationCallback(callback, globalObject));
    }

    virtual ~JSMutationCallback();

    void call(const Vector<Ref<MutationRecord>>&, MutationObserver*) override;
    bool canInvokeCallback() const override { return ActiveDOMCallback::canInvokeCallback(); }

private:
    JSMutationCallback(JSC::JSObject* callback, JSDOMGlobalObject*);

    mutable JSC::Weak<JSC::JSObject> m_callback;
    RefPtr<DOMWrapperWorld> m_isolatedWorld;
};

} // namespace WebCore

#endif
